==> ja-xdtp-1.1.4.tbz: include/xdtp/xmlloader.h <==
/*
 * $Id: xmlloader.h,v 1.4 2005/10/04 06:58:37 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.4 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___XMLLOADER_H
#define ___XMLLOADER_H

#include "libxml/parser.h"
#include "libxml/tree.h"

namespace XDTP {

class XMLLoader
{
protected:
    /**
     * 󥹥ȥ饯
     */
    XMLLoader();
    
    /**
     * ǥȥ饯
     */
    virtual ~XMLLoader();

public:
    /**
     * XMLե뤫ɤ߹ߤޤ
     * 
     * @param aPath XMLե
     * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
     */
    static xmlDocPtr load(const Glib::ustring& aPath);

    /**
     * XML꤫ɤ߹ߤޤ
     * 
     * @param aBuffer XMLʸ
     * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
     */
    static xmlDocPtr loadMem(const Glib::ustring& aBuffer);
};

};

#endif

==> ja-xdtp-1.3.1_2.tbz: include/xdtp/xmlloader.h <==
/*
 * $Id: xmlloader.h,v 1.5 2006/06/16 13:31:39 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.5 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___XMLLOADER_H
#define ___XMLLOADER_H

#include "libxml/parser.h"
#include "libxml/tree.h"

namespace XDTP {

class XMLLoader
{
protected:
    /**
     * 󥹥ȥ饯
     */
    XMLLoader();
    
    /**
     * ǥȥ饯
     */
    virtual ~XMLLoader();

public:
    /**
     * XMLե뤫ɤ߹ߤޤ
     * 
     * @param aPath XMLե
     * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
     */
    static xmlDocPtr load(const Glib::ustring& aPath);

    /**
     * XML꤫ɤ߹ߤޤ
     * 
     * @param aBuffer ХåեXMLʸ
     * @param aBytes ХåեĹ
     * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
     */
    static xmlDocPtr loadMem(const char* aBuffer, int aBytes);

    /**
     * XML꤫ɤ߹ߤޤ
     * 
     * @param aBuffer ХåեXMLʸ
     * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
     */
    static xmlDocPtr loadMem(const Glib::ustring& aBuffer);
};

};

#endif
